import { Component, OnInit } from '@angular/core';
import { AppService } from '../app.service';

@Component({
    moduleId: module.id,
    selector: 'pricechart',
    templateUrl: 'pricechart.component.html',
})
export class PriceChartComponent implements OnInit {

    private stocks: any = [];
    private chartOptions: IgDataChart;
    private errorMessage: any[];
    private desiredHeight: any;

    constructor(private _appService: AppService) {

    }

    ngOnInit() {
        this._appService.getStocks()
            .subscribe(
            stocks => this.stocks = stocks,
            error => this.errorMessage = <any>error);
        this.desiredHeight = 0.22 * (window.screen.height) + "px";
        this.chartOptions = this.getPriceChartOptions();
    }


    getPriceChartOptions() {

        return {
            axes: this.getPriceChartAxes(),
            series: this.getPriceChartSeries(),
            windowResponse: "deferred",
            horizontalZoomable: true,
            width: "100%",
            height: this.desiredHeight,
            theme: "metro",
            leftMargin: 0,
            rightMargin: 30,
            windowRectMinWidth: 0.05,
            syncChannel: "channel1",
            synchronizeVertically: false,
            syncrhonizeHorizontally: false
        };

    }

    getPriceChartAxes() {
        return [
            {
                name: "xAxis",
                type: "categoryX",
                label: "Date"
            },
            {
                name: "yAxis",
                type: "numericY",
                labelLocation: "outsideRight",
                majorStroke: "rgba(153,153,153,0.1)",
                labelExtent: 40

            }
        ];
    }

    getPriceChartSeries() {
        return [
            {
                name: "stockSeries",
                type: "splineArea",
                title: "Price Data",
                isHighlightingEnabled: true,
                isTransitionInEnabled: true,
                xAxis: "xAxis",
                yAxis: "yAxis",
                valueMemberPath: "High",
                showTooltip: true,
                Outline: "#00AADE"
            }
        ];
    }

}
